<template>
  <div class="commerce-contracts-container">
    <div class="project-codes">
      <h3>Project Codes</h3>
      <ul>
        <li
          v-for="project in uniqueProjectCodes"
          :key="project"
          :class="{ selected: selectedProject === project }"
          @click="selectProject(project)"
        >
          {{ project }}
        </li>
      </ul>
    </div>
    
    <div class="contracts-list">
      <h3>Sales Contracts</h3>
      <ul>
        <li 
          v-for="contract in filteredContracts('sale')" 
          :key="contract.contract_id"
        >
          {{ contract.contract_id }} - {{ contract.product }} - {{ contract.quantity_tons }} tons
        </li>
      </ul>
    </div>
    
    <div class="contracts-list">
      <h3>Purchase Contracts</h3>
      <ul>
        <li 
          v-for="contract in filteredContracts('purchase')" 
          :key="contract.contract_id"
        >
          {{ contract.contract_id }} - {{ contract.product }} - {{ contract.quantity_tons }} tons
        </li>
      </ul>
    </div>
  </div>
</template>

<script>
import { reactive, ref, onMounted } from 'vue';

export default {
  name: 'CommerceContracts',
  setup() {
    const commerceContracts = reactive([]);
    const selectedProject = ref(null);

    const joinRoom = () => {
      socket.emit('join_room_commerce_contracts');
      socket.on('commerce_contracts', (data) => {
        commerceContracts.length = 0;
        commerceContracts.push(...data);
        console.log(data);
      });
    };

    const attemptJoinRoom = () => {
      if (!commerceContracts.length) {
        joinRoom();
        setTimeout(attemptJoinRoom, 2000);
      }
    };

    onMounted(() => {
      joinRoom();
      setTimeout(attemptJoinRoom, 2000);
    });

    const uniqueProjectCodes = computed(() => {
      return [...new Set(commerceContracts.map(contract => contract.project_code))];
    });

    const selectProject = (project) => {
      selectedProject.value = selectedProject.value === project ? null : project;
    };

    const filteredContracts = (type) => {
      return commerceContracts.filter(contract => {
        return contract.contract_type === type && (!selectedProject.value || contract.project_code === selectedProject.value);
      });
    };

    return {
      commerceContracts,
      selectedProject,
      uniqueProjectCodes,
      selectProject,
      filteredContracts,
    };
  },
};
</script>

<style scoped>
.commerce-contracts-container {
  display: flex;
  justify-content: space-around;
  padding: 20px;
}

.project-codes, .contracts-list {
  width: 30%;
}

ul {
  list-style-type: none;
  padding: 0;
}

li {
  padding: 10px;
  border: 1px solid #ccc;
  margin: 5px 0;
  cursor: pointer;
  transition: all 0.3s ease;
}

li.selected {
  border-color: blue;
  background-color: rgba(173, 216, 230, 0.3);
}

h3 {
  text-align: center;
  margin-bottom: 15px;
}
</style>
